[commit: packages/Cabal] ghc-head: filterConfigureFlags: s/1.17/1.18/. (47b914c)

git at git.haskell.org git at git.haskell.org
Wed Sep 4 23:57:55 CEST 2013


Repository : ssh://git@git.haskell.org/Cabal

On branch  : ghc-head
Link       : http://git.haskell.org/?p=packages/Cabal.git;a=commit;h=47b914cfd3a2dad0cfadb0634cb7f1c64fd4a673

>---------------------------------------------------------------

commit 47b914cfd3a2dad0cfadb0634cb7f1c64fd4a673
Author: Mikhail Glushenkov <mikhail.glushenkov at gmail.com>
Date:   Thu Aug 29 14:25:20 2013 +0200

    filterConfigureFlags: s/1.17/1.18/.
    
    Some people have old snapshots of 1.17 installed, which causes build failures.


>---------------------------------------------------------------

47b914cfd3a2dad0cfadb0634cb7f1c64fd4a673
 cabal-install/Distribution/Client/Setup.hs |   14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/cabal-install/Distribution/Client/Setup.hs b/cabal-install/Distribution/Client/Setup.hs
index 0c82ab8..9301c26 100644
--- a/cabal-install/Distribution/Client/Setup.hs
+++ b/cabal-install/Distribution/Client/Setup.hs
@@ -241,21 +241,21 @@ configureOptions = commandOptions configureCommand
 
 filterConfigureFlags :: ConfigFlags -> Version -> ConfigFlags
 filterConfigureFlags flags cabalLibVersion
-  | cabalLibVersion >= Version [1,17,0] [] = flags
+  | cabalLibVersion >= Version [1,18,0] [] = flags
   | cabalLibVersion <  Version [1,3,10] [] = flags_1_3_10
   | cabalLibVersion <  Version [1,10,0] [] = flags_1_10_0
   | cabalLibVersion <  Version [1,14,0] [] = flags_1_14_0
-  | cabalLibVersion <  Version [1,17,0] [] = flags_1_17_0
+  | cabalLibVersion <  Version [1,18,0] [] = flags_1_18_0
 
   -- A no-op that silences the "pattern match is non-exhaustive" warning.
   | otherwise = flags
   where
-    -- Cabal < 1.17.0 doesn't know about --extra-prog-path and --sysconfdir.
-    flags_1_17_0 = flags        { configProgramPathExtra = []
-                                , configInstallDirs = configInstallDirs_1_17_0}
-    configInstallDirs_1_17_0 = (configInstallDirs flags) { sysconfdir = NoFlag }
+    -- Cabal < 1.18.0 doesn't know about --extra-prog-path and --sysconfdir.
+    flags_1_18_0 = flags        { configProgramPathExtra = []
+                                , configInstallDirs = configInstallDirs_1_18_0}
+    configInstallDirs_1_18_0 = (configInstallDirs flags) { sysconfdir = NoFlag }
     -- Cabal < 1.14.0 doesn't know about --disable-benchmarks.
-    flags_1_14_0 = flags_1_17_0 { configBenchmarks  = NoFlag }
+    flags_1_14_0 = flags_1_18_0 { configBenchmarks  = NoFlag }
     -- Cabal < 1.10.0 doesn't know about --disable-tests.
     flags_1_10_0 = flags_1_14_0 { configTests       = NoFlag }
     -- Cabal < 1.3.10 does not grok the constraints flag.





More information about the ghc-commits mailing list